﻿Imports System.Collections.ObjectModel
Imports C1.Silverlight.Chart

Partial Public Class MainPage
    Inherits UserControl

    Dim dragManager As C1.Silverlight.C1DragDropManager = New C1.Silverlight.C1DragDropManager()
    Dim dataList As ObservableCollection(Of MyDataClass) = New ObservableCollection(Of MyDataClass)

    Public Sub New()
        InitializeComponent()

        SetupGrid()
        SetupChart()

        dragManager.RegisterDropTarget(c1Chart1, True)
        dragManager.RegisterDropTarget(c1DataGrid1, True)

        AddHandler dragManager.DragDrop, AddressOf dragManager_DragDrop
    End Sub

    Private Sub dragManager_DragDrop(ByVal source As Object, ByVal e As C1.Silverlight.DragDropEventArgs)
        ' Add the Series for the field dragged on the Chart control
        If e.DropTarget.GetType.Equals(GetType(C1.Silverlight.Chart.C1Chart)) Then
            Dim draggedfield As String = CType(CType(e.DragSource, C1.Silverlight.DataGrid.DataGridColumnHeaderPresenter).Content, TextBlock).Text
            Dim fieldValues As List(Of Double) = New List(Of Double)
            ' Get the Series values from the ObservableCollection
            If (draggedfield = "UnitPrice") Then
                fieldValues = (From val In dataList Select val.UnitPrice).ToList()
            Else
                fieldValues = (From val In dataList Select val.UnitsInStock).ToList()
            End If

            If ((c1Chart1.Data.Children.Count = 1) _
                        AndAlso (c1Chart1.Data.Children(0).Label = "dummy")) Then
                c1Chart1.Data.Children.Clear()
            End If
            ' Check if series has already been added in Chart
            For Each ds As DataSeries In c1Chart1.Data.Children
                If (ds.Label = draggedfield) Then
                    Return
                End If
            Next
            ' add series to the chart
            Dim ds1 As DataSeries = New DataSeries
            ds1.Label = draggedfield
            ds1.ValuesSource = fieldValues.ToList
            AddHandler ds1.PlotElementLoaded, AddressOf Me.ds1_PlotElementLoaded
            c1Chart1.Data.Children.Add(ds1)

            ' Reset the Axis Min and Max as per 
            ' the values of new DataSeries
            Dim fldMin As Double = fieldValues.Min
            If (fldMin < c1Chart1.View.AxisY.Min) Then
                c1Chart1.View.AxisY.Min = fldMin
            End If
            Dim fldMax As Double = fieldValues.Max
            If (fldMax > c1Chart1.View.AxisY.Max) Then
                c1Chart1.View.AxisY.Max = fldMax
            End If
        Else
            ' Remove the series for the Chart bar dragged on to the Grid 
            c1Chart1.Data.Children.Remove(CType(e.DragSource, PlotElement).DataPoint.Series)
            If (c1Chart1.Data.Children.Count = 0) Then
                SetupChart()
            End If
        End If


    End Sub
    Public Sub ds1_PlotElementLoaded(ByVal sender As Object, ByVal e As EventArgs)

        Dim pe As PlotElement = CType(sender, PlotElement)
        dragManager.RegisterDragSource(pe, C1.Silverlight.DragDropEffect.Copy, ModifierKeys.None)

    End Sub

    Public Sub SetupGrid()
        dataList.Add(New MyDataClass("Chai", 18.0, 39.0))
        dataList.Add(New MyDataClass("Chang", 19.0, 17.0))
        dataList.Add(New MyDataClass("Ikura", 31.0, 31.0))
        dataList.Add(New MyDataClass("Pavlova", 17.45, 29.0))
        dataList.Add(New MyDataClass("Tunnbröd", 9.0, 61.0))
        dataList.Add(New MyDataClass("Gravad lax", 26.0, 11.0))
        dataList.Add(New MyDataClass("Geitost", 25.0, 50.0))
        dataList.Add(New MyDataClass("Chocolade", 12.75, 15))
        dataList.Add(New MyDataClass("Pâté chinois", 24.0, 30))
        c1DataGrid1.ItemsSource = dataList

    End Sub

    Private Sub c1DataGrid1_LoadedColumnHeaderPresenter(sender As Object, e As C1.Silverlight.DataGrid.DataGridColumnEventArgs) Handles c1DataGrid1.LoadedColumnHeaderPresenter
        If e.Column.Index > 0 Then
            dragManager.RegisterDragSource(e.Column.HeaderPresenter, C1.Silverlight.DragDropEffect.Copy, ModifierKeys.None)
        End If
    End Sub

    Public Sub SetupChart()
        c1Chart1.Data.Children.Clear()
        Dim list As List(Of String) = (From prod In dataList Select prod.ProductName).ToList()

        c1Chart1.View.AxisY.Max = 10
        c1Chart1.View.AxisY.AutoMax = False
        c1Chart1.View.AxisY.Min = 0
        c1Chart1.View.AxisY.AutoMin = False
        c1Chart1.View.AxisX.AnnoAngle = 90
        Dim PriceX() As Integer = New Integer() {0, 0, 0, 0, 0, 0, 0, 0}
        Dim ds1 As DataSeries = New DataSeries
        ds1.Label = "dummy"
        'set price data
        ds1.ValuesSource = PriceX
        ' add series to the chart
        c1Chart1.Data.Children.Add(ds1)
        ' add item names
        c1Chart1.Data.ItemNames = list.ToArray
        ' Set chart type
        c1Chart1.ChartType = ChartType.Column
    End Sub


End Class

Public Class MyDataClass

    Public Sub New(ByVal mPName As String, ByVal mUPrice As Double, ByVal mUStock As Double)
        _pName = mPName
        _uPrice = mUPrice
        _uStock = mUStock
    End Sub

    Dim _pName As String
    Public Property ProductName As String
        Get
            Return _pName
        End Get
        Set(value As String)
            _pName = value
        End Set
    End Property

    Dim _uPrice As Double
    Public Property UnitPrice As Double
        Get
            Return _uPrice
        End Get
        Set(value As Double)
            _uPrice = value
        End Set
    End Property

    Dim _uStock As Double
    Public Property UnitsInStock As Double
        Get
            Return _uStock
        End Get
        Set(value As Double)
            _uStock = value
        End Set
    End Property
End Class